from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x99\x08\x00\x00\x00\x00\x00\x18\x79\xd4\x96\x97\x3b\xe1\xc6\x6a\x9b\xbc\x16\xd7\x0f\x7e\x1b\x0d\x00\x00\x00\x00\x00\x00\x00\x00\x16\x3e\x67\xa6\x21\xb5\x00\x60\x40\x10\x9d\xe9\x36\x7b\xf2\xee\xbd\x6f\xf8\xca\xf8\x01\xea\x7e\xd2\x7d\x81\xb7\xbf\x4e\xb7\x6b\x8a\x85\x25\x40\x44\x92\xfc\x22\x20\xc0\x43\x49\x8b\x47\x90\xb2\x84\x2b\xfe\x49\x70\xd0\x87\xe8\xe3\x6f\xb2\xfc\x69\x8a\x0d\xf8\x69\xb6\xbb\xe7\x1a\x65\xd4\x57\x90\x06\x25\x38\xd3\xe9\x6c\x17\x47\x09\x9c\x98\x9a\xf0\x00\x8d\x0f\x63\xae\xb6\xb5\xd6\x7b\xe5\x0e\x23\x7d\x45\xd0\xb0\x41\xb9\x34\x4f\x29\xb1\x08\x58\xd9\xf7\x7e\xbb\x23\x95\xd1\x37\xe2\x6d\x52\xd5\xe7\xad\x00\xd8\xf9\xad\xdb\x01\x6a\x7b\x6e\xff\x4e\xa6\x09\x42\xa7\x96\x6a\x45\xa1\x47\xaf\x59\x42\x4d\xa6\xab\x60\xa4\x75\x1c\x2d\x6a\x27\xbd\x5d\x6c\xd3\xee\x23\x67\x45\x80\xa8\xa6\x72\xcb\x61\x2d\x33\x3e\x99\xaa\xe9\x49\x48\xdf\xaf\x55\xe9\xcf\xa9\x7c\xf7\x3e\x46\xed\x3c\x00\xd4\x9f\xd7\x87\xd7\x28\x84\x9d\x1b\xea\xf4\x29\x84\x08\xb7\x54\xac\x34\xf8\x30\x91\x54\xb6\x9d\xc4\xb2\x44\x34\x03\x2e\x54\x15\x12\xdd\x7e\xd8\xf8\x15\xc5\x1f\x21\x3b\x70\x75\xfd\x63\x82\x90\xfb\x3b\x9c\x22\x68\xa0\x4e\xd2\x9f\xf0\xda\xd3\xdd\x4f\x2f\x68\xfe\x16\xa0\xf2\xfd\x86\x7d\xdb\x6e\xb5\x65\xae\x31\xdd\x19\x07\xa3\x62\x93\xa2\x19\xf4\x8b\x58\xd0\x09\xe2\x34\x85\xa5\x78\xb7\xdf\x29\xfa\x11\x5f\x18\x44\x23\x3d\x1a\x21\x2c\xf1\xdb\x36\xeb\xaa\xd3\xf2\x68\x57\x98\x14\xd8\x03\x17\x4a\x21\x22\x76\xcd\xd7\xd9\x28\x47\x46\x97\x22\xca\x56\xd6\xea\x70\x16\x6a\x53\x8b\xfe\x37\x89\xad\x79\xfa\xbc\x4b\xe6\x22\xfe\xf4\xb1\x08\x06\xc5\x7e\x83\xdb\xdd\x51\x47\x5e\xbb\x33\x20\x2f\xb2\x47\x2f\x47\x69\xb2\x77\x2a\x8d\xa6\x2c\x0c\x2e\x2e\x80\x88\xac\xe1\xb8\x63\x3b\x50\x4f\x83\x6d\xe0\x65\xc5\xd6\x75\xb8\x7e\x0b\x16\x8e\xdc\xa3\x98\x30\x94\x87\x00\xd6\x0f\x15\x3c\xa7\xae\x3d\xc9\x35\xc4\xc3\xbc\x51\x39\xb6\x85\x38\xe7\x26\xf9\xe5\xe3\x8d\xeb\xc8\x55\x29\x57\xe3\x21\x96\xb2\xc5\x91\x81\x56\x3a\x91\x07\x86\xa5\xb8\x2e\x65\x89\x25\x12\x47\x37\xee\x67\x62\x13\x14\x6b\x38\x5b\xdb\x1a\x93\xbe\x98\x03\x50\xa1\xd8\x55\xac\x5d\x3d\x90\xd1\xe5\x2f\x49\x77\x88\x91\x28\xbe\xd3\x51\xe1\x50\xd1\x3b\xd7\xa5\x05\xf9\xa1\x5f\xc1\xa4\xd0\xe0\x57\x43\x92\x2c\x5c\x59\x4f\x3e\x02\x3d\xc9\x60\x1e\xed\xf2\xd4\xef\x9d\x96\x15\x01\x3a\x70\xd4\xbb\xdc\x19\xe1\x8a\xe1\x55\x6a\xaa\xf0\x01\x31\x86\xe3\xf5\xf9\xff\x06\x30\x9e\x30\x91\x19\x68\x45\xca\x99\xa0\x5d\x41\x4a\xbe\x33\x4f\x74\x8f\xf5\xec\x00\xa1\xdd\xa7\xa5\x47\x23\x67\x11\xd0\x08\xa7\x38\x9c\x0b\xe2\x5f\xbb\x72\x46\xfe\x71\x95\xb7\x29\x57\x1e\x70\xb4\x9b\xd7\x25\x23\x81\x4b\xaa\xf9\x47\x95\xba\xae\xd2\xc5\x01\xc3\x02\xc7\xa4\x7b\x1e\x45\x57\x1c\x25\xb6\xc7\x1f\x20\x09\x37\xd0\xa1\x8b\x42\xb8\xc8\x69\x2f\x43\x61\xdf\xab\x49\xce\xa7\x11\x71\xd2\x20\x40\xcd\xc6\x3f\xed\x83\x7c\x7e\x4a\x91\x38\x18\x4e\x89\x71\x75\x64\x0c\x97\xef\x30\xf3\xe3\x13\x09\xab\x9c\xc3\x7e\x66\x5d\x72\xf6\xd7\x86\x96\x6d\x7c\xd4\xc6\xa4\x30\x4b\x71\xa5\x4f\x30\xd6\x01\x88\xb6\xe0\x78\x1e\xb5\xe3\xaf\x49\x20\xab\x67\x2a\xd1\xfd\x16\x01\x03\xd3\xf0\x3a\x2b\x86\x26\x4d\x61\xda\x02\x7e\xe9\x56\xb6\x94\x77\x6e\xae\xbe\x26\x9b\x4f\x0d\x90\x96\x94\x76\xbe\x6e\xc9\x45\x85\x77\xfa\x6c\xfb\xda\x28\xc8\x28\xdf\x01\xec\x6c\x9c\xba\xd0\x2b\x15\x76\xa1\x05\xd8\x3a\x2b\x42\x5d\x8d\xfc\x55\xdf\x92\xf4\xb5\xb4\x04\x85\x42\x12\xb3\x51\xfb\x81\x59\x6e\x7b\x9e\xdb\x85\x0e\x2c\x85\x1c\x59\x75\xfb\x96\x95\x08\xff\x7b\xbb\xf1\xb3\xf8\xf2\x61\x98\xbf\x4a\xaf\x8a\x05\x44\x40\x85\x70\x6e\xe8\x1f\x79\x4a\x73\xb9\xc3\x84\xfe\xd6\x39\x2d\x0a\xdb\x2b\xa9\xa7\x75\x1c\x00\x35\x2c\xe5\x3e\xb9\x96\x1d\x5e\x21\x5e\xb1\x82\xc9\x9b\x71\x9f\xc1\x01\x44\x13\x14\xb2\x86\x6e\xa6\x00\xae\xab\x27\x73\x37\x29\x56\x30\x10\xf0\xad\x38\xc0\x57\x0c\x9b\xec\x0b\xae\x6c\xbe\x35\xe7\x43\xbd\xd3\x41\x75\x87\x0d\x61\xb0\xcb\x7d\xe0\x0d\x5e\xe9\xf3\x5a\xf6\x31\x01\x38\x57\x98\x84\xd1\x02\x69\x2c\xab\x03\xe5\xaf\x3b\x26\xc1\xba\x57\x5c\x6b\x6d\x9a\x71\xb6\x59\x79\xcc\x34\x81\xf7\x83\x03\x0c\xa4\x50\x95\x99\xcf\x73\xd2\x11\x89\x13\x29\x01\x26\x52\xc5\xb9\x08\xfe\xdd\x2a\xd2\x36\xc4\x46\xbf\x90\x66\x5e\x0b\x84\x0f\x8c\x05\x3a\x6c\xaf\xf0\xa7\xd0\xe7\x39\xf0\xc0\x4e\xb4\x05\x92\x96\xf6\x98\x5f\x31\x80\xfa\x27\x43\x3d\x08\x0b\x28\x5e\x65\x01\x42\xa6\x47\x27\x99\xe5\x08\x67\x0b\xa4\x86\x53\xbc\xdb\x73\x07\x6f\x32\x1f\xc2\x02\x78\x58\x0c\x79\x99\xdd\xc2\xfc\x26\xb6\xfe\x2f\x1a\x59\xea\x7a\x44\x78\x45\xeb\x4d\xf4\x33\x33\x5c\xd2\x02\x8c\xec\x70\x7a\x7b\x77\x9d\xbe\x77\x65\xca\x1d\x50\x0f\xed\xb3\x5e\x7b\xd1\x23\x32\xe0\x90\x2a\x78\x55\x8f\x3a\x78\xa3\xbe\xc2\x20\x67\x99\x7a\xfb\xc0\xd2\xb7\x97\x0b\x9d\x0c\x16\x29\xe1\xcf\x42\x66\x16\x36\xfa\x9d\x95\x65\x23\x70\x28\xf1\x45\x11\x8a\x27\x3c\x65\x7c\xae\x9e\x7b\x16\x4b\x25\xf7\xed\xfd\xb5\xa8\x3d\x9a\x93\x4c\x0a\x88\x97\x93\x03\xde\xa3\x61\xbd\x8c\x1d\xc4\xf9\x50\xd4\x25\xd0\xfe\x6b\x45\x88\x9c\x66\xdc\xce\x93\xbe\x55\x66\xe7\x2f\xd7\x3e\x35\xc1\xcb\x2f\x09\x4c\xc5\x9b\x52\x11\x25\x42\x35\x25\x1b\x7e\x02\x2a\x33\xfe\x07\x1e\xa3\x4e\x25\x4c\xf8\x4e\x22\x63\xfc\x5e\xf1\x79\x2d\x7b\xf8\x9b\xfb\x11\x12\xa9\xa6\x7a\xdf\xd5\xcf\xc5\xaa\xad\x6d\x99\xd8\xa4\x1d\x27\x0f\xdc\x10\x91\x1b\x78\x57\xe2\x10\x6b\x88\x79\xb3\xec\x81\x9e\x49\xb2\x0b\xf3\x3e\x10\x1d\xae\x7b\x97\x0c\xfc\x00\x68\x47\xa7\x14\xb3\x70\xaf\xf4\x6c\xc0\xcf\xe4\xdb\xab\xd6\x3c\x60\xf0\xfa\x9a\x8d\x49\x0c\xcf\x95\x46\x90\x2c\x20\xb9\xcb\x6a\x61\x6a\x00\xac\xf2\xd9\x96\x6e\x8e\x19\xd5\x5a\xeb\x6d\x42\xfc\xdd\x12\x4d\x7f\xac\x12\x59\xdd\x40\x1d\xf0\x60\x5c\x6e\x04\x0a\xaa\xd0\x12\xdf\x22\x72\xdb\x16\x98\x20\x51\x6c\xc3\x30\x40\xff\x64\x7d\x96\x04\x34\x0a\xd8\x8f\x22\xde\x97\x80\x0e\x5a\x7b\x3a\x9f\xbf\xa2\x86\x83\x35\x20\x89\x5a\xef\xa9\xc5\x16\x8a\x66\x68\xc0\x71\x31\x5d\x97\x72\xdc\xb1\x5f\xfe\x68\xa2\xe2\xfc\x91\x2e\xa3\x94\x52\x4e\x4b\xac\x73\x80\xeb\xd6\x9b\xf8\x19\xc9\xd9\x19\x65\x47\xdc\x3f\xb1\x7b\x63\x7a\x8d\x63\xc5\xf6\x92\x2f\x6b\x9d\xe7\xea\xe6\xd3\xa4\xcd\x37\x9d\x47\xc6\xba\x54\xd9\x04\xb8\x8d\x72\xa6\x76\xae\x2d\xc9\xb3\x24\x78\x54\x9a\xdf\x97\x36\x66\x7a\xba\x5e\x2e\xce\x81\x0b\xec\x7c\xb7\xbf\xf5\x14\x01\x1f\x3c\x05\xa2\xbc\x1b\x8d\xda\xb9\xf6\x5b\xc4\x26\xfb\xee\x49\x2a\x6e\xdf\xcd\x68\xe5\x5d\x92\xb4\x5f\xb8\xf5\x82\x2c\x0e\xbb\x6d\xa5\x3f\x93\xb5\x0e\x7d\x58\x2c\x2f\x02\xc0\x61\x8a\x1a\x2c\xe9\xdf\xa1\x33\xd7\x6a\x71\x01\x13\x32\x4c\x49\x08\x48\xb3\x53\x07\xbf\x41\x31\xc9\xe2\x56\x97\xa1\xdf\xbf\xfe\x46\x18\xb6\x12\x7d\x0d\xc1\x24\x3e\xd3\x61\x2b\x89\x53\x6c\x4e\x11\x87\x96\xd0\x8e\x63\xcd\xda\x26\x1a\xe3\x53\xa0\x64\x16\x71\x70\x7c\xc2\x93\x79\x45\x78\x0b\x30\x26\xc6\x0c\xa3\xa1\x49\x6f\x3d\x34\x80\xaf\x97\xcc\xea\x1e\xf6\x19\xd5\x45\xb1\xa2\xa0\x65\xcb\x24\x24\xfc\xd0\x0c\x46\x6f\xc2\x52\x07\x1d\x50\x07\x24\xb2\x72\xb2\x09\xaf\x07\x01\x50\x14\xaf\xcd\xee\x73\x1e\xb3\xa4\x2d\x8d\x68\x05\x8a\xc5\x6d\x39\x70\xf3\x12\x37\x5d\x3c\x8e\xe9\x99\xb2\x42\xcf\xea\x87\x71\x82\x2a\x70\xff\x37\xdd\x98\xe8\xcb\x5c\x1f\xa8\x19\x48\xda\xd7\x2d\xf9\xc0\x79\xf9\xba\xf1\x1c\xbe\x0d\x8d\x14\xb8\x94\x31\x4f\xa3\xf8\x20\x82\x07\x6a\xc0\xc0\xf2\x89\xe8\x2f\x56\x7b\xa9\x61\x94\xfc\x35\xeb\xe0\x21\xdb\x7f\xdd\x4c\xe9\xfb\x8f\xce\x1b\xa5\x1b\x06\xbd\xba\x52\x0b\xa8\x86\xc9\x73\x00\xe3\x05\x3a\xdb\x6f\x33\xfe\xc0\x8f\xf0\x05\xd9\x0c\xbe\x0f\x88\x41\x3f\x4c\x12\xc3\x27\x29\x0f\x19\xa2\xd1\xea\x16\x75\x91\xb9\xfb\x82\x31\xa5\x72\x8f\x7a\xee\xa0\x0f\x4c\x0a\x70\x55\xf8\x75\xd7\x5f\x8f\xaf\x9b\x52\xdb\x5b\xe7\xf0\x89\x0a\xb9\x18\x9f\xac\xc3\x21\x57\x83\xd8\x5f\xc6\xdb\x7b\x48\xa3\x7e\xb4\xd7\x2b\xcb\x33\x54\xd5\x69\x28\x34\xf7\x86\xee\x68\xf7\x7f\x70\xfd\xa4\x5f\xa1\xb0\x51\x94\x82\x41\x54\x3e\x54\x99\xbb\x69\x38\x59\xb4\x65\xc4\xfc\x7d\x0d\xf9\x9a\x34\x75\xb1\xfb\x72\x60\x01\xd1\x22\xc9\xb7\xb7\x7e\xcf\x9e\x82\xdc\x7c\xe4\x65\xb8\xfc\xbf\xd4\x35\x0a\xdd\x79\x50\xb4\x7e\xa9\xf4\x2e\xf1\x51\x50\x99\x13\xc5\xdf\x99\xf2\xba\xa6\x33\xba\xb9\xe9\xbf\x85\x1f\x16\x50\xf4\x4e\x12\xb3\xfc\xac\x52\xde\xed\xe7\xf5\xf9\xe3\xcd\x2a\x4f\xe0\x49\x83\x2d\xf1\xb2\x27\x3d\x1a\x6a\xb0\xd2\x51\x60\xdf\x9d\xce\x20\x8b\x11\x44\x7e\x69\x07\x69\xeb\xb6\xac\xff\x88\xea\x38\x37\x4d\x90\x8a\xb8\x61\xab\x67\xc5\xc6\x02\x1f\x46\xfc\xab\x25\x1f\x98\x83\x6a\x73\x7a\x09\x87\xdf\x30\x80\x63\xed\xc9\x44\x54\x2c\x34\xa9\x10\x11\x2e\x89\x3b\x94\x24\xc3\x82\xfe\xc4\xd3\x6c\x33\x54\x49\x20\x65\xba\xf3\x90\xe5\x3f\x2d\x55\x05\xad\xe1\xdd\x81\x86\xcb\x75\xb8\x4f\xb5\x12\xa9\xe0\xae\x90\xea\xa9\x7d\xda\x41\xe3\x90\xff\x6b\x31\xad\x99\xc9\x28\x89\xfd\x37\x4a\xad\xe1\x01\x62\x16\x0d\x08\x4e\x42\x17\xa8\x75\xc8\xbf\x5a\x62\x84\xa4\x72\xe6\x60\x23\x88\x28\x3c\xd4\x9c\x65\x3a\x36\x92\x30\x6c\x82\x8d\x25\xa1\x0c\x8e\xae\x45\x4a\x23\x90\xa1\x29\xf4\x41\xb9\xe9\x5e\x4d\x0a\x7b\x74\x75\xb9\x5c\xdd\x5a\x7c\x0d\x7b\x33\x1d\x8f\x8f\x5c\xa5\x03\xd6\xb9\xee\xb2\x0c\xc9\xae\x2a\x7f\x0d\x55\x44\x22\x44\x4f\xef\x1d\x6d\x47\xdb\x74\x58\xc1\x25\x76\x86\x18\xe1\x8c\xbb\x30\x93\x85\x14\x37\x6c\x09\x72\x45\x8a\x98\x5c\x29\x2b\xff\x19\x1b\x87\x79\xce\x3c\xd9\x61\x63\x6c\x43\xdc\x85\x54\x04\x9b\x70\x2c\x7f\xb8\x11\x60\x85\xbf\xf8\xa5\x91\x7d\x48\x74\x63\x29\xf0\xc0\x5f\x33\x0d\x67\x1a\xf1\xcc\x4c\x48\xa7\xf2\x54\x32\x13\x64\xfb', 2)

# cleanup
del pyarmor_runtime

